im_flutter_sdk library

Classes

ChatAreaCode
ChatClient
~english The ChatClient class, which is the entry point of the Chat SDK. With this class, you can log in, log out, and access other functionalities such as group and chatroom. ~end
ChatCmdMessageBody
~english The command message body. ~end
ChatContact
ChatContactChangeEvent
ChatContactEventHandler
~english The contact event handler.
ChatContactManager
~english The contact manager class, which manages chat contacts such as adding, deleting, retrieving, and modifying contacts. ~end
ChatConversation
~english The conversation class, indicating a one-to-one chat, a group chat, or a conversation chat. It contains the messages that are sent and received within the conversation.
ChatCursorResult<T>
~english The ChatCursorResult class, which specifies the cursor from which to query results. When querying using this class, the SDK returns the queried instance and the cursor.
ChatCustomMessageBody
~english The custom message body. ~end
ChatDeviceInfo
~english The ChatDeviceInfo class, which contains the multi-device information. ~end
ChatDownloadCallback
~english The group shared download callback. ~end
ChatError
~english The error class defined by the SDK. ~end
ChatEventHandler
~english The chat event handler.
ChatFileMessageBody
~english The base class of file messages. ~end
ChatGroup
~english The ChatGroup class, which contains the information of the chat group. ~end
ChatGroupChangeEvent
ChatGroupEventHandler
~english The group event handler.
ChatGroupInfo
~english The class that defines basic information of chat groups. ~end
ChatGroupManager
~english The group manager class, which manages group creation and deletion, user joining and exiting the group, etc. ~end
ChatGroupMessageAck
~english The class for group message read receipts.
ChatGroupOptions
~english The group options to be configured when the chat group is created. ~end
ChatGroupSharedFile
~english The ChatGroupSharedFile class, which manages the chat group shared files.
ChatImageMessageBody
~english The image message body class. ~end
ChatLocationMessageBody
~english The location message class. ~end
ChatManager
~english The chat manager class, responsible for sending and receiving messages, loading and deleting conversations, and downloading attachments.
ChatMessage
~english The message class.
ChatMessageBody
ChatMessageEvent
~english The message status event class. During message delivery, the message ID will be changed from a local uuid to a global unique ID that is generated by the server to uniquely identify a message on all devices using the SDK. This API should be implemented in the chat page widget to listen for message status changes. ~end
ChatMessageReaction
~english The message Reaction instance class, which has the following attributes: Reaction: The message Reaction. UserCount: The count of users that added the Reaction. UserList: The list of users that added the Reaction. isAddedBySelf: Whether the current user added this Reaction. ~end
ChatMessageReactionEvent
~english The message reaction change event class. ~end
ChatMessageSenderInfo
~english The message sender info class, which contains the user attributes of the message sender. ~end
ChatMethodKeys
ChatMultiDeviceEventHandler
~english The multi-device event handler. Listens for the callback for the current user's actions on other devices, including contact changes, group changes, and thread changes.
ChatOptions
~english The ChatOptions class, which contains the settings of the Chat SDK.
ChatPageResult<T>
~english The ChatPageResult class, which is returned when calling the methods that fetch data by pagination. The SDK also returns the number of remaining pages and the data count of the next page. If the dada count is less than the count you set, there is no more data on server.
ChatPresence
~english The presence property class that contains presence properties, including the publisher's user ID and current presence state, and the platform used by the online device, as well as the presence's extension information, update time, and subscription expiration time. ~end
ChatPresenceEventHandler
~english The presence event handler.
ChatPresenceManager
~english The Manager that defines how to manage presence states. ~end
ChatPresenceStatusDetail
~english The presence details, including the platform used by the publisher's current online device and the current presence state. ~end
ChatPushConfig
~english The push configuration class, which contains the push configuration information, such as the push style. ~end
ChatPushConfigs
~english The push configuration class. ~end
ChatPushManager
~english The message push configuration options. ~end
ChatRoom
~english The chat room instance class.
ChatRoomEvent
ChatRoomEventHandler
~english The chat room event handler.
ChatRoomManager
~english The chat room manager class, which manages user joining and exiting the chat room, retrieving the chat room list, and managing member privileges. The sample code for joining a chat room:
ChatSilentModeParam
~english Offline push Settings parameter entity class. ~end
ChatSilentModeResult
~english Offline push DND result class. ~end
ChatSilentModeTime
~english For offline push DND time class. ~end
ChatStreamChunk
~english The stream message chunk. ~end
ChatTextMessageBody
~english The text message class. ~end
ChatThread
~english The message thread class. ~end
ChatThreadEvent
~english The message thread event class. ~end
ChatThreadEventHandler
~english The message thread event handler, which handles message thread events such as creating or leaving a message thread.
ChatThreadManager
~english The chat thread manager class. ~end
ChatTranslateLanguage
~english The translation language class, which contains the information of the translation languages. ~end
ChatUserInfo
~english The ChatUserInfo class, which contains the user attributes, such as the nickname, description, and avatar. ~end
ChatUserInfoChangeEvent
ChatUserInfoEventHandler
~english The user info event handler.
ChatUserInfoManager
~english The user attribute manager class, which gets and sets the user attributes. ~end
ChatVideoMessageBody
~english The video message body class. ~end
ChatVoiceMessageBody
~english The voice message body class. ~end
ChatVoiceParam
~english The voice file parameter class, which describes the format of the voice file to be converted to text. ~end
CombineMessageBody
ConnectionEventHandler
~english The connection event handler.
ConversationFetchOptions
~english The conversation filter class. ~end
ExtSettings
FetchMessageOptions
~english The parameter configuration class for pulling historical messages from the server. ~end
GroupMemberInfo
~english The group member info class, which contains the group member information. ~end
LoginExtensionInfo
MessageCallBackManager
MessagePinInfo
~english The message pinning information. ~end
MessageSearchOptions
ReactionOperation
~english Reaction operation. ~end
RecallMessageInfo

Enums

ChatConversationType
~english The conversation types. ~end
ChatGroupPermissionType
~english The group roles. ~end
ChatGroupStyle
~english The group types. ~end
ChatMultiDevicesEvent
~english Multi-device event types.
ChatPushRemindType
~english The push notification modes. ~end
ChatRoomMessagePriority
~english Chat room message priorities. ~end
ChatRoomPermissionType
~english The chat room roles. ~end
ChatSearchDirection
~english The message search directions. ~end
ChatSilentModeParamType
~english The offline push settings. ~end
ChatStreamStatus
~english The stream message chunk status. ~end
ChatThreadOperation
~english The message thread events. ~end
ChatType
~english The chat types.
ChatVoiceFormat
~english The voice file format. ~end
ConversationMarkType
~english The conversation mark types.
DisplayStyle
~english The push display styles. ~end
DownloadStatus
~english The download status of the attachment file. ~end
LeaveReason
~english Leave chat room reason ~end ~chinese 离开聊天室原因 ~end
MessageDirection
~english The message directions.
MessagePinOperation
MessageSearchScope
~english The message search scopes. ~end
MessageStatus
~english The message sending/reception status. ~end
MessageType
~english The message types. ~end
ReactionOperate
~english Reaction operations. ~end

Typedefs

CursorResultCallback = Object Function(dynamic obj)
EMChatEventHandler = ChatEventHandler
EMChatManager = ChatManager
EMChatRoom = ChatRoom
EMChatRoomEvent = ChatRoomEvent
EMChatRoomEventHandler = ChatRoomEventHandler
EMChatRoomManager = ChatRoomManager
EMChatRoomPermissionType = ChatRoomPermissionType
EMChatThread = ChatThread
EMChatThreadEvent = ChatThreadEvent
EMChatThreadEventHandler = ChatThreadEventHandler
EMChatThreadManager = ChatThreadManager
EMChatThreadOperation = ChatThreadOperation
EMClient = ChatClient
EMCmdMessageBody = ChatCmdMessageBody
EMCombineMessageBody = CombineMessageBody
EMConnectionEventHandler = ConnectionEventHandler
EMContact = ChatContact
EMContactChangeEvent = ChatContactChangeEvent
EMContactEventHandler = ChatContactEventHandler
EMContactManager = ChatContactManager
EMConversation = ChatConversation
EMConversationType = ChatConversationType
EMCursorResult<T> = ChatCursorResult<T>
EMCustomMessageBody = ChatCustomMessageBody
EMDeviceInfo = ChatDeviceInfo
EMDownloadCallback = ChatDownloadCallback
EMError = ChatError
EMFileMessageBody = ChatFileMessageBody
EMGroup = ChatGroup
EMGroupChangeEvent = ChatGroupChangeEvent
EMGroupEventHandler = ChatGroupEventHandler
EMGroupInfo = ChatGroupInfo
EMGroupManager = ChatGroupManager
EMGroupMessageAck = ChatGroupMessageAck
EMGroupOptions = ChatGroupOptions
EMGroupPermissionType = ChatGroupPermissionType
EMGroupSharedFile = ChatGroupSharedFile
EMGroupStyle = ChatGroupStyle
EMImageMessageBody = ChatImageMessageBody
EMLocationMessageBody = ChatLocationMessageBody
EMMessage = ChatMessage
EMMessageBody = ChatMessageBody
EMMessageReaction = ChatMessageReaction
EMMessageReactionEvent = ChatMessageReactionEvent
EMMessageSenderInfo = ChatMessageSenderInfo
EMMultiDeviceEventHandler = ChatMultiDeviceEventHandler
EMMultiDevicesEvent = ChatMultiDevicesEvent
EMOptions = ChatOptions
EMPageResult<T> = ChatPageResult<T>
EMPresence = ChatPresence
EMPresenceEventHandler = ChatPresenceEventHandler
EMPresenceManager = ChatPresenceManager
EMPresenceStatusDetail = ChatPresenceStatusDetail
EMPushConfig = ChatPushConfig
EMPushConfigs = ChatPushConfigs
EMPushManager = ChatPushManager
EMSearchDirection = ChatSearchDirection
EMStreamChunk = ChatStreamChunk
EMStreamStatus = ChatStreamStatus
EMTextMessageBody = ChatTextMessageBody
EMTranslateLanguage = ChatTranslateLanguage
EMUserInfo = ChatUserInfo
EMUserInfoChangeEvent = ChatUserInfoChangeEvent
EMUserInfoEventHandler = ChatUserInfoEventHandler
EMUserInfoManager = ChatUserInfoManager
EMVideoMessageBody = ChatVideoMessageBody
EMVoiceFormat = ChatVoiceFormat
EMVoiceMessageBody = ChatVoiceMessageBody
EMVoiceParam = ChatVoiceParam
PageResultCallback = Object Function(dynamic obj)