ChatContact class
Constructors
- ChatContact(Map map)
- ChatContact.fromJson(Map map)
-
factory
Properties
- addTimestamp → int?
-
~english
The timestamp when the contact is added, in milliseconds.
~end
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- remark → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
- userInfo → ChatUserInfo?
-
~english
The user attributes of the contact.
~end
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited