ChatVoiceFormat enum

~english The voice file format. ~end

~chinese 语音文件格式。 ~end

Inheritance
Available extensions

Values

pcm → const ChatVoiceFormat

~english The PCM format. ~end

~chinese PCM 格式。 ~end

mp3 → const ChatVoiceFormat

~english The MP3 format. ~end

~chinese MP3 格式。 ~end

amr → const ChatVoiceFormat

~english The AMR format. ~end

~chinese AMR 格式。 ~end

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChatVoiceFormat>
A constant List of the values in this enum, in order of their declaration.