EMGroupChangeEvent class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- ON_ADMIN_ADDED → const String
- ON_ADMIN_REMOVED → const String
- ON_ALL_MEMBER_MUTE_STATE_CHANGED → const String
- ON_ANNOUNCEMENT_CHANGED → const String
- ON_ATTRIBUTES_CHANGED_OF_MEMBER → const String
- ON_AUTO_ACCEPT_INVITATION → const String
- ON_GROUP_DESTROYED → const String
- ON_INVITATION_ACCEPTED → const String
- ON_INVITATION_DECLINED → const String
- ON_INVITATION_RECEIVED → const String
- ON_MEMBER_EXITED → const String
- ON_MEMBER_JOINED → const String
- ON_MUTE_LIST_ADDED → const String
- ON_MUTE_LIST_REMOVED → const String
- ON_OWNER_CHANGED → const String
- ON_REQUEST_TO_JOIN_ACCEPTED → const String
- ON_REQUEST_TO_JOIN_DECLINED → const String
- ON_REQUEST_TO_JOIN_RECEIVED → const String
- ON_SHARED_FILE__DELETED → const String
- ON_SHARED_FILE_ADDED → const String
- ON_SPECIFICATION_DID_UPDATE → const String
- ON_STATE_CHANGED → const String
- ON_USER_REMOVED → const String
- ON_WHITE_LIST_ADDED → const String
- ON_WHITE_LIST_REMOVED → const String